@@ -54,7 +54,7 @@ PIG__0_12_HADOOP_2 = "0.12-Hadoop-2"
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
-                         cluster_tags=[]):
+                         cluster_tags=[], instance_type=None):
     """
     Post a new job to a new cluster.
 
@@ -97,6 +97,12 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :type job_type: string
     :param job_type: Type of the job. Default: pig.
 
+    :type cluster_tags: list
+    :param cluster_tags: Tags that will be assigned to a new cluster.
+
+    :type instance_type: string
+    :param instance_type: Instance type for the core nodes of a new cluster.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -105,6 +111,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     body = {'project_name': project_name,
             'git_ref': git_ref,
             'cluster_size': cluster_size,
+            'instance_type': instance_type,
             'cluster_type': cluster_type,
             'cluster_tags': cluster_tags,
             'parameters': parameters or {},
